aboutsummaryrefslogtreecommitdiff
path: root/engines/glk/frotz/frotz.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'engines/glk/frotz/frotz.cpp')
-rw-r--r--engines/glk/frotz/frotz.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/glk/frotz/frotz.cpp b/engines/glk/frotz/frotz.cpp
index 0e516f0496..f30acd0a4b 100644
--- a/engines/glk/frotz/frotz.cpp
+++ b/engines/glk/frotz/frotz.cpp
@@ -24,12 +24,12 @@
#include "glk/frotz/frotz_types.h"
#include "common/config-manager.h"
-namespace Gargoyle {
+namespace Glk {
namespace Frotz {
Frotz *g_vm;
-Frotz::Frotz(OSystem *syst, const GargoyleGameDescription *gameDesc) :
+Frotz::Frotz(OSystem *syst, const GlkGameDescription *gameDesc) :
Processor(syst, gameDesc) {
g_vm = this;
}
@@ -95,4 +95,4 @@ Common::Error Frotz::saveGameState(int slot, const Common::String &desc) {
}
} // End of namespace Scott
-} // End of namespace Gargoyle
+} // End of namespace Glk